From 05d4825e5850d2a67a3d4e2eefc971d257d5112d Mon Sep 17 00:00:00 2001
From: vogelor <vogelor@ispconfig3>
Date: Mon, 10 May 2010 14:37:53 -0400
Subject: [PATCH] The new version is only displayed for the admin (aargh)

---
 interface/web/admin/groups_list.php |    7 ++-----
 1 files changed, 2 insertions(+), 5 deletions(-)

diff --git a/interface/web/admin/groups_list.php b/interface/web/admin/groups_list.php
index 3545f04..f75f5de 100644
--- a/interface/web/admin/groups_list.php
+++ b/interface/web/admin/groups_list.php
@@ -41,11 +41,8 @@
 * End Form configuration
 ******************************************/
 
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],$_SESSION["s"]["module"]["name"])) {
-	header("Location: ../index.php");
-	exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('admin');
 
 $app->uses('listform_actions');
 $app->listform_actions->onLoad();

--
Gitblit v1.9.1